import { AttachMessageTransport } from '@tracerbench/message-transport';
import { Chrome } from '@tracerbench/spawn-chrome';
import { default as findChrome } from '@tracerbench/find-chrome';
import { default as openWebSocket } from '@tracerbench/websocket-message-transport';
import { Process } from '@tracerbench/spawn';
import { RaceCancellation } from 'race-cancellation';
import { RootConnection } from '@tracerbench/protocol-connection';
import { SpawnOptions } from '@tracerbench/spawn-chrome';
import { Stdio } from '@tracerbench/spawn';

export declare interface ChromeWithPipeConnection extends Chrome {
    /**
     * Connection to devtools protocol https://chromedevtools.github.io/devtools-protocol/
     */
    connection: RootConnection;
    /**
     * Close browser.
     */
    close(timeout?: number, raceCancellation?: RaceCancellation): Promise<void>;
}
export { findChrome }

export declare function newProtocolConnection(attach: AttachMessageTransport, raceCancellation?: RaceCancellation): RootConnection;
export { openWebSocket }

export declare interface ProcessWithPipeConnection extends Process {
    /**
     * Connection to devtools protocol https://chromedevtools.github.io/devtools-protocol/
     */
    connection: RootConnection;
    /**
     * Close browser.
     */
    close(timeout?: number, raceCancellation?: RaceCancellation): Promise<void>;
}

export declare interface ProcessWithWebSocketConnection extends Process {
    /**
     * Connection to devtools protocol https://chromedevtools.github.io/devtools-protocol/
     */
    connection: RootConnection;
    /**
     * Closes the web socket.
     */
    close(): void;
}

export declare function spawnChrome(options?: Partial<SpawnOptions>): ChromeWithPipeConnection;

export declare function spawnWithPipe(executable: string, args: string[], stdio?: Stdio): ProcessWithPipeConnection;

export declare function spawnWithWebSocket(executable: string, args: string[], stdio?: Stdio, raceCancellation?: RaceCancellation): Promise<ProcessWithWebSocketConnection>;

export * from "@tracerbench/message-transport";
export * from "@tracerbench/protocol-connection/types";
export * from "@tracerbench/spawn-chrome/types";
export * from "@tracerbench/spawn/types";

export { }
